@@ -14,11 +14,7 @@ with 'Firewall::Config::Element::Address::Role';
 #------------------------------------------------------------------------------
 # Firewall::Config::Element::Address::Srx 通用属性
 #------------------------------------------------------------------------------
-has zone => (
-  is       => 'ro',
-  isa      => 'Str',
-  required => 1,
-);
+has zone => ( is => 'ro', isa => 'Str', required => 1, );
 
 #------------------------------------------------------------------------------
 # 重写 Firewall::Config::Element::Role => _buildSign 方法，
