@@ -15,17 +15,9 @@ with 'Firewall::Config::Element::AddressGroup::Role';
 #------------------------------------------------------------------------------
 # Firewall::Config::Element::AddressGroup::Netscreen 通用属性
 #------------------------------------------------------------------------------
-has zone => (
-  is       => 'ro',
-  isa      => 'Str',
-  required => 1,
-);
+has zone => ( is => 'ro', isa => 'Str', required => 1, );
 
-has description => (
-  is      => 'ro',
-  isa     => 'Undef|Str',
-  default => undef,
-);
+has description => ( is => 'ro', isa => 'Undef|Str', default => undef, );
 
 #------------------------------------------------------------------------------
 # 重写 Firewall::Config::Element::Role => _buildSign 方法，
