@@ -13,11 +13,7 @@ with 'Firewall::Config::Element::Role';
 #------------------------------------------------------------------------------
 # Firewall::Config::Element::Protocol::Role 通用方法
 #------------------------------------------------------------------------------
-has protocol => (
-  is       => 'ro',
-  isa      => 'Str',
-  required => 1,
-);
+has protocol => ( is => 'ro', isa => 'Str', required => 1, );
 
 #------------------------------------------------------------------------------
 # Moose BUILDARGS 在实例创建之前生效，可以接收哈希和哈希的引用
