@@ -14,43 +14,17 @@ with 'Firewall::Config::Element::Route::Role';
 #------------------------------------------------------------------------------
 # Firewall::Config::Element::Route::Fortinet 通用属性
 #------------------------------------------------------------------------------
-has routeId => (
-  is       => 'ro',
-  isa      => 'Int',
-  required => 0,
-);
+has routeId => ( is => 'ro', isa => 'Int', required => 0, );
 
-has type => (
-  is      => 'ro',
-  isa     => 'Str',
-  default => 'static',
-);
+has type => ( is => 'ro', isa => 'Str', default => 'static', );
 
-has srcInterface => (
-  is       => 'ro',
-  isa      => 'Str|Undef',
-  required => 0,
-);
+has srcInterface => ( is => 'ro', isa => 'Str|Undef', required => 0, );
 
-has srcIpmask => (
-  is       => 'ro',
-  isa      => 'Str|Undef',
-  required => 0,
-);
+has srcIpmask => ( is => 'ro', isa => 'Str|Undef', required => 0, );
 
-has srcRange => (
-  is       => 'ro',
-  required => 0,
-  isa      => 'Firewall::Utils::Set',
-  lazy     => 1,
-  builder  => '_buildSrcRange',
-);
+has srcRange => ( is => 'ro', required => 0, isa => 'Firewall::Utils::Set', lazy => 1, builder => '_buildSrcRange', );
 
-has dstInterface => (
-  is       => 'ro',
-  isa      => 'Str|Undef',
-  required => 0,
-);
+has dstInterface => ( is => 'ro', isa => 'Str|Undef', required => 0, );
 
 #------------------------------------------------------------------------------
 # 重写 Firewall::Config::Element::Role => _buildRange 方法
