@@ -14,41 +14,17 @@ with 'Firewall::Config::Element::Route::Role';
 #------------------------------------------------------------------------------
 # Firewall::Config::Element::Route::Neteye 通用属性
 #------------------------------------------------------------------------------
-has '+network' => (
-  is       => 'ro',
-  isa      => 'Str',
-  required => 0,
-);
+has '+network' => ( is => 'ro', isa => 'Str', required => 0, );
 
-has '+mask' => (
-  is       => 'ro',
-  isa      => 'Int',
-  required => 0,
-);
+has '+mask' => ( is => 'ro', isa => 'Int', required => 0, );
 
-has type => (
-  is      => 'ro',
-  isa     => 'Str',
-  default => 'static',
-);
+has type => ( is => 'ro', isa => 'Str', default => 'static', );
 
-has srcInterface => (
-  is       => 'ro',
-  isa      => 'Str|Undef',
-  required => 0,
-);
+has srcInterface => ( is => 'ro', isa => 'Str|Undef', required => 0, );
 
-has srcRange => (
-  is       => 'ro',
-  required => 0,
-  isa      => 'Firewall::Utils::Set|Undef',
-);
+has srcRange => ( is => 'ro', required => 0, isa => 'Firewall::Utils::Set|Undef', );
 
-has dstInterface => (
-  is       => 'ro',
-  isa      => 'Str|Undef',
-  required => 0,
-);
+has dstInterface => ( is => 'ro', isa => 'Str|Undef', required => 0, );
 
 #------------------------------------------------------------------------------
 # 重写 Firewall::Config::Element::Role => _buildRange 方法
