@@ -42,35 +42,15 @@ trange mode commands/options:
 #------------------------------------------------------------------------------
 # Firewall::Config::Element::Schedule::Asa 通用属性
 #------------------------------------------------------------------------------
-has startDate => (
-  is      => 'ro',
-  isa     => 'Undef|Str',
-  default => undef,
-);
+has startDate => ( is => 'ro', isa => 'Undef|Str', default => undef, );
 
-has endDate => (
-  is      => 'ro',
-  isa     => 'Undef|Str',
-  default => undef,
-);
+has endDate => ( is => 'ro', isa => 'Undef|Str', default => undef, );
 
-has periodic => (
-  is      => 'ro',
-  isa     => 'Undef|Str',
-  default => undef,
-);
+has periodic => ( is => 'ro', isa => 'Undef|Str', default => undef, );
 
-has startTime => (
-  is      => 'ro',
-  isa     => 'Undef|Str',
-  default => undef,
-);
+has startTime => ( is => 'ro', isa => 'Undef|Str', default => undef, );
 
-has endTime => (
-  is      => 'ro',
-  isa     => 'Undef|Str',
-  default => undef,
-);
+has endTime => ( is => 'ro', isa => 'Undef|Str', default => undef, );
 
 #------------------------------------------------------------------------------
 # 重写 Firewall::Config::Element::Role => _buildRange 方法
@@ -146,10 +126,7 @@ sub createTimeRange {
       my ( $min, $max ) = ( $self->startTime, $self->endTime );
       $min =~ s/://;
       $max =~ s/://;
-      my $range = {
-        min => $min + 0,
-        max => $max + 0
-      };
+      my $range = {min => $min + 0, max => $max + 0};
       my @weekDays;
       if ( $self->periodic eq 'daily' ) {
         @weekDays = qw/ Sunday Monday Tuesday Wednesday Thursday Friday Saturday /;
