@@ -15,54 +15,22 @@ with 'Firewall::Config::Element::StaticNat::Role';
 #------------------------------------------------------------------------------
 # Firewall::Config::Element::StaticNat::Hillstone 通用属性
 #------------------------------------------------------------------------------
-has id => (
-  is       => 'ro',
-  isa      => 'Str',
-  required => 1,
-);
+has id => ( is => 'ro', isa => 'Str', required => 1, );
 
-has realIp => (
-  is       => 'ro',
-  isa      => 'Str',
-  required => 1,
-);
+has realIp => ( is => 'ro', isa => 'Str', required => 1, );
 
-has realIpRange => (
-  is      => 'ro',
-  isa     => 'Firewall::Utils::Set',
-  default => sub { Firewall::Utils::Set->new },
-);
+has realIpRange => ( is => 'ro', isa => 'Firewall::Utils::Set', default => sub { Firewall::Utils::Set->new }, );
 
-has natIp => (
-  is       => 'ro',
-  isa      => 'Str',
-  required => 1,
-);
+has natIp => ( is => 'ro', isa => 'Str', required => 1, );
 
-has natIpRange => (
-  is      => 'ro',
-  isa     => 'Firewall::Utils::Set',
-  lazy    => 1,
-  default => sub { Firewall::Utils::Set->new },
-);
+has natIpRange =>
+  ( is => 'ro', isa => 'Firewall::Utils::Set', lazy => 1, default => sub { Firewall::Utils::Set->new }, );
 
-has natInterface => (
-  is       => 'ro',
-  isa      => 'Str | Undef',
-  required => 0,
-);
+has natInterface => ( is => 'ro', isa => 'Str | Undef', required => 0, );
 
-has natZone => (
-  is       => 'ro',
-  isa      => 'Str',
-  required => 0,
-);
+has natZone => ( is => 'ro', isa => 'Str', required => 0, );
 
-has realZone => (
-  is       => 'ro',
-  isa      => 'Str',
-  required => 0,
-);
+has realZone => ( is => 'ro', isa => 'Str', required => 0, );
 
 #------------------------------------------------------------------------------
 # 重写 Firewall::Config::Element::Role => _buildRange 方法
